@@ -22,6 +22,9 @@ import google.api_core.exceptions
 import google.auth.transport
 from google.auth.transport import requests
 import google.oauth2
+from cloudpathlib import AnyPath
+
+from cpg_utils.config import get_config
 
 
 def email_from_id_token(id_token_jwt: str) -> str:
@@ -284,3 +287,30 @@ def _get_default_id_token_credentials(
             return current_credentials
 
     raise exceptions.DefaultCredentialsError(_HELP_MESSAGE)
+
+
+def get_cached_group_members(group, members_cache_location: str = None) -> set[str]:
+    """
+    Get cached members of a group, based on the members_cache_location
+    """
+    group_name = group.split('@')[0]
+
+    if not members_cache_location:
+        config = get_config()
+        members_cache_location = config['infrastructure']['members_cache_location']
+
+    pathname = os.path.join(members_cache_location, group_name + '-members.txt')  # type: ignore
+
+    with AnyPath(pathname).open() as f:
+        return set(line.strip() for line in f.readlines() if line.strip())
+
+
+def is_member_in_cached_group(
+    group, member, members_cache_location: str = None
+) -> bool:
+    """
+    Check if a member is in a group, based on the infrastructure config
+    """
+    return member in get_cached_group_members(
+        group, members_cache_location=members_cache_location
+    )
